package com.blazinggames.urcl.text;

import java.util.Hashtable;

/**
 * Ultimate Retro Common Library
 * Copyright (C) 2001, 2003-2004 Blazing Games Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * ------------------------------------------------
 * 
 * A text based instructions handler. Instructions should be in the resource
 * manager text block format, with the table of contents assigned the key 0,
 * and pages being given numbers between 1 and 98. Page 99 is reserved for
 * exiting the instructions, though I can't see there being that many pages.
 * These defaults can be changed.
 * 
 * @author Billy D. Spelchan
 * @version OSR1.00
 */
public class Instructions
{
    // *********************
    // ***** CONSTANTS *****
    // *********************

    public static final String CONTENTS = "0";
    public static final String EXIT = "99";
    public static final String MESSAGE = "Type 0 for contents, 99 to exit.";
    public static final String PROMPT = "Page? ";
    public static final String ERROR = "Page not found.";


    // *********************
    // ***** VARIABLES *****
    // *********************

    private Hashtable _instructions;
    private String _toc;
    private String _exit;
    private String _message;
    private String _prompt;
    private String _error;


    // ************************
    // ***** CONSTRUCTORs *****
    // ************************

    public Instructions()
    {
        this(new Hashtable());
    }

    public Instructions(Hashtable data)
    {
        if (data != null)
            _instructions = data;
        else
            _instructions = new Hashtable();
        _toc = CONTENTS;
        _exit = EXIT;
        _message = MESSAGE;
        _prompt = PROMPT;
        _error = ERROR;
    }


    // *****************************************
    // ***** METHODS - Getting and Setting *****
    // *****************************************

    public final void setInstructions(Hashtable data)
    {
        if (data != null)
            _instructions = data;
        else
            _instructions = new Hashtable();
    }

    public final Hashtable getInstructions()
    {
        return _instructions;
    }

    public final void setContentString(String s)
    {
        _toc = s;
    }

    public final String getContentString()
    {
        return _toc;
    }

    public final void setExitString(String s)
    {
        _exit = s;
    }

    public final String getExitString()
    {
        return _exit;
    }

    public final void setMessage(String s)
    {
        _message = s;
    }

    public final String getMessage()
    {
        return _message;
    }

    public final void setPromp(String s)
    {
        _prompt = s;
    }

    public final String getPrompt()
    {
        return _prompt;
    }

    public final void setErrorString(String s)
    {
        _error = s;
    }

    public final String getErrorString()
    {
        return _error;
    }


    // *****************************
    // ***** METHODS - Actions *****
    // *****************************

    public void showPage(TextDisplay out, String page)
    {
        String text[] = (String[])_instructions.get(page);

        if (text == null)
        {
            out.println(_error);
            return;
        }
        for (int cntr = 0; cntr < text.length; ++cntr)
        {
            out.println(text[cntr]);
        }
    }

    public void showInstructions(TextDisplay out)
    {
        String s = _toc;
        do
        {
            showPage(out, s);
            out.println();
            if (_message != null)
                out.println(_message);
            out.print(_prompt);
            s = out.input();
            out.println(s);
        }
        while (_exit.equalsIgnoreCase(s) == false);
    }
}
